from __future__ import annotations

import pytest
from .. import resources
from textstat.backend import selections


@pytest.mark.parametrize(
    "text, rm_punctuation, rm_apostrophe, lowercase, split_contractions,"
    " split_hyphens, expected",
    [
        (resources.EMPTY_STR, False, False, False, False, False, []),
        (resources.EASY_WORD, False, False, False, False, False, [resources.EASY_WORD]),
        (
            resources.EASY_WORD,
            False,
            False,
            True,
            False,
            False,
            [resources.EASY_WORD.lower()],
        ),
        (
            resources.DIFFICULT_WORD,
            False,
            False,
            True,
            False,
            False,
            [resources.DIFFICULT_WORD.lower()],
        ),
        (
            resources.PUNCT_TEXT,
            False,
            False,
            False,
            False,
            False,
            resources.PUNCT_TEXT.split(),
        ),
        (
            resources.PUNCT_TEXT,
            True,
            False,
            False,
            False,
            False,
            [
                "I",
                "said",
                "This",
                "is",
                "a",
                "test",
                "sentence",
                "to",
                "test",
                "the",
                "remove_punctuation",
                "function",
                "It's",
                "short",
                "and",
                "not",
                "the",
                "work",
                "of",
                "a",
                "singersongwriter",
                "But",
                "it'll",
                "suffice",
                "Your",
                "answer",
                "was",
                "I",
                "don't",
                "know",
                "If",
                "I",
                "were",
                "you",
                "I'd",
                "write",
                "a",
                "test",
                "just",
                "to",
                "make",
                "sure",
                "you're",
                "really",
                "just",
                "removing",
                "the",
                "characters",
                "you",
                "want",
                "to",
                "remove",
                "Didn't",
            ],
        ),
        (
            resources.PUNCT_TEXT,
            True,
            False,
            False,
            True,
            False,
            [
                "I",
                "said",
                "This",
                "is",
                "a",
                "test",
                "sentence",
                "to",
                "test",
                "the",
                "remove_punctuation",
                "function",
                "It",
                "s",
                "short",
                "and",
                "not",
                "the",
                "work",
                "of",
                "a",
                "singersongwriter",
                "But",
                "it",
                "ll",
                "suffice",
                "Your",
                "answer",
                "was",
                "I",
                "don",
                "t",
                "know",
                "If",
                "I",
                "were",
                "you",
                "I",
                "d",
                "write",
                "a",
                "test",
                "just",
                "to",
                "make",
                "sure",
                "you",
                "re",
                "really",
                "just",
                "removing",
                "the",
                "characters",
                "you",
                "want",
                "to",
                "remove",
                "Didn",
                "t",
            ],
        ),
        (
            resources.PUNCT_TEXT,
            True,
            True,
            False,
            False,
            False,
            [
                "I",
                "said",
                "This",
                "is",
                "a",
                "test",
                "sentence",
                "to",
                "test",
                "the",
                "remove_punctuation",
                "function",
                "Its",
                "short",
                "and",
                "not",
                "the",
                "work",
                "of",
                "a",
                "singersongwriter",
                "But",
                "itll",
                "suffice",
                "Your",
                "answer",
                "was",
                "I",
                "dont",
                "know",
                "If",
                "I",
                "were",
                "you",
                "Id",
                "write",
                "a",
                "test",
                "just",
                "to",
                "make",
                "sure",
                "youre",
                "really",
                "just",
                "removing",
                "the",
                "characters",
                "you",
                "want",
                "to",
                "remove",
                "Didnt",
            ],
        ),
        (
            resources.PUNCT_TEXT,
            True,
            True,
            False,
            True,
            False,
            [
                "I",
                "said",
                "This",
                "is",
                "a",
                "test",
                "sentence",
                "to",
                "test",
                "the",
                "remove_punctuation",
                "function",
                "Its",
                "short",
                "and",
                "not",
                "the",
                "work",
                "of",
                "a",
                "singersongwriter",
                "But",
                "itll",
                "suffice",
                "Your",
                "answer",
                "was",
                "I",
                "dont",
                "know",
                "If",
                "I",
                "were",
                "you",
                "Id",
                "write",
                "a",
                "test",
                "just",
                "to",
                "make",
                "sure",
                "youre",
                "really",
                "just",
                "removing",
                "the",
                "characters",
                "you",
                "want",
                "to",
                "remove",
                "Didnt",
            ],
        ),
        (
            resources.PUNCT_TEXT,
            False,
            True,
            False,
            False,
            False,
            resources.PUNCT_TEXT.split(),
        ),
        (
            resources.PUNCT_TEXT,
            True,
            True,
            True,
            False,
            False,
            [
                "i",
                "said",
                "this",
                "is",
                "a",
                "test",
                "sentence",
                "to",
                "test",
                "the",
                "remove_punctuation",
                "function",
                "its",
                "short",
                "and",
                "not",
                "the",
                "work",
                "of",
                "a",
                "singersongwriter",
                "but",
                "itll",
                "suffice",
                "your",
                "answer",
                "was",
                "i",
                "dont",
                "know",
                "if",
                "i",
                "were",
                "you",
                "id",
                "write",
                "a",
                "test",
                "just",
                "to",
                "make",
                "sure",
                "youre",
                "really",
                "just",
                "removing",
                "the",
                "characters",
                "you",
                "want",
                "to",
                "remove",
                "didnt",
            ],
        ),
        (
            resources.PUNCT_TEXT,
            True,
            True,
            True,
            True,
            True,
            [
                "i",
                "said",
                "this",
                "is",
                "a",
                "test",
                "sentence",
                "to",
                "test",
                "the",
                "remove_punctuation",
                "function",
                "its",
                "short",
                "and",
                "not",
                "the",
                "work",
                "of",
                "a",
                "singer",
                "songwriter",
                "but",
                "itll",
                "suffice",
                "your",
                "answer",
                "was",
                "i",
                "dont",
                "know",
                "if",
                "i",
                "were",
                "you",
                "id",
                "write",
                "a",
                "test",
                "just",
                "to",
                "make",
                "sure",
                "youre",
                "really",
                "just",
                "removing",
                "the",
                "characters",
                "you",
                "want",
                "to",
                "remove",
                "didnt",
            ],
        ),
    ],
)
def test_list_words(
    text: str,
    rm_punctuation: bool,
    rm_apostrophe: bool,
    lowercase: bool,
    expected: list[str],
    split_contractions: bool,
    split_hyphens: bool,
) -> None:
    assert (
        selections.list_words(
            text,
            rm_punctuation,
            rm_apostrophe,
            lowercase,
            split_contractions,
            split_hyphens,
        )
        == expected
    )
